## *Function* `draw_motif(dm, negative_edge_color: str = "r", pos=None)`


Draw a dotmotif motif object.

### Arguments
> - **dm** (`None`: `None`): dotmotif.Motif
> - **negative_edge_color** (`str`: `r`): Color used to represent negative edges
> - **pos** (`dict`: `None`): The position to use. If unset, uses nx.spring_layout

### Returns
    None

